@@ -17,18 +17,23 @@ Camera Models
 """
 import base64
 import math
+import os
 from dataclasses import dataclass
+from distutils.util import strtobool
 from enum import Enum, auto
 from typing import Dict, List, Optional, Tuple, Union
 
 import cv2
 import torch
 import torchvision
+from torch.nn import Parameter
 from torchtyping import TensorType
 
+import nerfstudio.utils.math
 import nerfstudio.utils.poses as pose_utils
 from nerfstudio.cameras import camera_utils
 from nerfstudio.cameras.rays import RayBundle
+from nerfstudio.data.scene_box import SceneBox
 from nerfstudio.utils.tensor_dataclass import TensorDataclass
 
 
@@ -141,6 +146,8 @@ class Cameras(TensorDataclass):
 
         self.__post_init__()  # This will do the dataclass post_init and broadcast all the tensors
 
+        self._use_nerfacc = strtobool(os.environ.get("INTERSECT_WITH_NERFACC", "TRUE"))
+
     def _init_get_fc_xy(self, fc_xy, name):
         """
         Parses the input focal length / principle point x or y and returns a tensor of the correct shape
@@ -223,7 +230,7 @@ class Cameras(TensorDataclass):
             c_x_y: cx or cy for when h_w == None
         """
         if isinstance(h_w, int):
-            h_w = torch.Tensor([h_w]).to(torch.int64).to(self.device)
+            h_w = torch.as_tensor([h_w]).to(torch.int64).to(self.device)
         elif isinstance(h_w, torch.Tensor):
             assert not torch.is_floating_point(h_w), f"height and width tensor must be of type int, not: {h_w.dtype}"
             h_w = h_w.to(torch.int64).to(self.device)
@@ -231,7 +238,7 @@ class Cameras(TensorDataclass):
                 h_w = h_w.unsqueeze(-1)
         # assert torch.all(h_w == h_w.view(-1)[0]), "Batched cameras of different h, w will be allowed in the future."
         elif h_w is None:
-            h_w = torch.Tensor((c_x_y * 2).to(torch.int64).to(self.device))
+            h_w = torch.as_tensor((c_x_y * 2)).to(torch.int64).to(self.device)
         else:
             raise ValueError("Height must be an int, tensor, or None, received: " + str(type(h_w)))
         return h_w
@@ -308,6 +315,7 @@ class Cameras(TensorDataclass):
         distortion_params_delta: Optional[TensorType["num_rays":..., 6]] = None,
         keep_shape: Optional[bool] = None,
         disable_distortion: bool = False,
+        aabb_box: Optional[SceneBox] = None,
     ) -> RayBundle:
         """Generates rays for the given camera indices.
 
@@ -350,6 +358,7 @@ class Cameras(TensorDataclass):
                 keeping dimensions. If False, we flatten at the end. If True, then we keep the shape of the
                 camera_indices and coords tensors (if we can).
             disable_distortion: If True, disables distortion.
+            aabb_box: if not None will calculate nears and fars of the ray according to aabb box intesection
 
         Returns:
             Rays for the given camera indices and coords.
@@ -449,6 +458,27 @@ class Cameras(TensorDataclass):
         if keep_shape is False:
             raybundle = raybundle.flatten()
 
+        if aabb_box:
+            with torch.no_grad():
+                tensor_aabb = Parameter(aabb_box.aabb.flatten(), requires_grad=False)
+
+                rays_o = raybundle.origins.contiguous()
+                rays_d = raybundle.directions.contiguous()
+
+                tensor_aabb = tensor_aabb.to(rays_o.device)
+                shape = rays_o.shape
+
+                rays_o = rays_o.reshape((-1, 3))
+                rays_d = rays_d.reshape((-1, 3))
+
+                t_min, t_max = nerfstudio.utils.math.intersect_aabb(rays_o, rays_d, tensor_aabb)
+
+                t_min = t_min.reshape([shape[0], shape[1], 1])
+                t_max = t_max.reshape([shape[0], shape[1], 1])
+
+                raybundle.nears = t_min
+                raybundle.fars = t_max
+
         # TODO: We should have to squeeze the last dimension here if we started with zero batch dims, but never have to,
         # so there might be a rogue squeeze happening somewhere, and this may cause some unintended behaviour
         # that we haven't caught yet with tests
