@@ -449,6 +449,15 @@ class VolumetricSampler(Sampler):
 
         rays_o = ray_bundle.origins.contiguous()
         rays_d = ray_bundle.directions.contiguous()
+
+        if ray_bundle.nears is not None and ray_bundle.fars is not None:
+            t_min = ray_bundle.nears.contiguous().reshape(-1)
+            t_max = ray_bundle.fars.contiguous().reshape(-1)
+
+        else:
+            t_min = None
+            t_max = None
+
         if ray_bundle.camera_indices is not None:
             camera_indices = ray_bundle.camera_indices.contiguous()
         else:
@@ -457,6 +466,8 @@ class VolumetricSampler(Sampler):
         ray_indices, starts, ends = nerfacc.ray_marching(
             rays_o=rays_o,
             rays_d=rays_d,
+            t_min=t_min,
+            t_max=t_max,
             scene_aabb=self.scene_aabb,
             grid=self.occupancy_grid,
             # this is a workaround - using density causes crash and damage quality. should be fixed
@@ -492,6 +503,8 @@ class VolumetricSampler(Sampler):
             ),
             camera_indices=camera_indices,
         )
+        if ray_bundle.times is not None:
+            ray_samples.times = ray_bundle.times[ray_indices]
         return ray_samples, ray_indices
 
 
