@@ -39,3 +39,11 @@ def check_colmap_installed():
         CONSOLE.print("[bold red]Could not find COLMAP. Please install COLMAP.")
         print("See https://colmap.github.io/install.html for installation instructions.")
         sys.exit(1)
+
+
+def check_curl_installed():
+    """Checks if curl is installed."""
+    curl_path = shutil.which("curl")
+    if curl_path is None:
+        CONSOLE.print("[bold red]Could not find [yellow]curl[red], Please install [yellow]curl")
+        sys.exit(1)
